@@ -2,7 +2,7 @@ use strict;
 use warnings;
 package RTx::RemoteLinks;
 
-our $VERSION = '0.03';
+our $VERSION = '1.00';
 
 use List::Util 'first';
 
@@ -77,7 +77,7 @@ sub CanonicalizeAlias {
     };
 }
 
-=head1 INSTALLATION 
+=head1 INSTALLATION
 
 =over
 
@@ -91,7 +91,11 @@ May need root permissions
 
 =item Edit your F</opt/rt4/etc/RT_SiteConfig.pm>
 
-Add this line:
+If you are using RT 4.2 or greater, add this line:
+
+    Plugin('RTx::RemoteLinks');
+
+For 4.0, add this line:
 
     Set(@Plugins, qw(RTx::RemoteLinks));
 
@@ -109,19 +113,21 @@ Configure your remote RT instances per L</CONFIGURATION> above.
 
 =head1 AUTHOR
 
-Thomas Sibley <trs@bestpractical.com>
+Best Practical Solutions, LLC E<lt>modules@bestpractical.comE<gt>
 
 =head1 BUGS
 
 All bugs should be reported via email to
-L<bug-RTx-RemoteLinks@rt.cpan.org|mailto:bug-RTx-RemoteLinks@rt.cpan.org>
-or via the web at
-L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RTx-RemoteLinks>.
 
+    L<bug-RTx-RemoteLinks@rt.cpan.org|mailto:bug-RTx-RemoteLinks@rt.cpan.org>
+
+or via the web at
+
+    L<rt.cpan.org|http://rt.cpan.org/Public/Dist/Display.html?Name=RTx-RemoteLinks>.
 
 =head1 LICENSE AND COPYRIGHT
 
-This software is Copyright (c) 2013 by Best Practical Solutions
+This software is Copyright (c) 2013-2014 by Best Practical Solutions, LLC
 
 This is free software, licensed under:
 
